import requests


def mex_cancel_order(order_id, mex_id):
    url = 'https://food-max-api.stg-myteksi.com/foodmaxapi/v1/cancel-order/{}'.format(order_id)
    headers = {
        "X-Grab-ID-ServiceUserID": str(mex_id),
        "X-Grab-ID-ServiceID": "FOODMAX"
    }
    data = {
        "orderID": order_id,
        "cancelReason": "We're too busy right now",
        "cancelCode": 1002
    }
    response = requests.put(url, headers=headers, data=data, verify=False)
    if response.status_code != 204:
        raise ValueError('Failed to cancel order {}'.format(order_id))


def get_order(order_id):
    headers = {
        'accept': 'application/json',
        'content-type': 'application/json'
    }
    url = 'https://food-order-manager.stg-myteksi.com/foodordermanager/orders/{}'.format(order_id)
    response = requests.get(url, headers=headers)
    if response.status_code != 200:
        raise ValueError('Failed to get order {}'.format(order_id))
    else:
        return response.json()


def get_booking(booking_code):
    headers = {
        'accept': 'application/json',
        'content-type': 'application/json'
    }

    url = 'http://bookings.stg-myteksi.com/v3/bookings/{}/'.format(booking_code)

    response = requests.get(url, headers=headers)
    if response.status_code != 200:
        raise ValueError('Failed to get booking {}'.format(booking_code))
    else:
        return response.json()


def get_batching(batchID):
    url = 'https://food-order-batching.stg-myteksi.com/foodorderbatching/deliverybatch/batch/{}'.format(batchID)
    response = requests.get(url)
    if response.status_code != 200:
        raise ValueError('Failed to get batching {}'.format(batchID))
    else:
        return response.json()


def get_delivery_data(booking_code, driver_id):
    url = 'https://food-delivery-taskpool.stg-myteksi.com/fooddeliveryv2/deliveryData/{}/detail'.format(
        booking_code)
    headers = {'Grab-Food-Driver-ID': driver_id}
    response = requests.get(url, headers=headers)
    if response.status_code != 200:
        raise ValueError('Failed to get delivery task detail for booking {}'.format(booking_code))
    else:
        return response.json()


def get_poi_address(lat, lng):
    url = 'https://poi-int.stg-myteksi.com/services/poi/reverse_geo?reference={},{}'.format(lat, lng)
    response = requests.get(url)
    if response.status_code != 200:
        raise ValueError('Failed to get POI address for {}, {}'.format(lat, lng))
    else:
        return response.json()


def get_pax_express_home(user_id, lat, lng):
    url = 'https://grab-express-int.stg-myteksi.com/passenger/v3/homefeeds?latitude={}&longitude={}'.format(lat, lng)
    headers = {'X-Grab-ID-ServiceUserID': user_id}
    response = requests.get(url, headers=headers)
    if response.status_code != 200:
        raise ValueError('Failed to get homepage data for {}'.format(user_id))
    else:
        return response.json()


def get_express_ongoing_orders_info(user_id):
    url = 'https://grab-express-int.stg-myteksi.com/passenger/v2/ongoing'
    headers = {'X-Grab-ID-ServiceUserID': user_id}
    response = requests.get(url, headers=headers)
    if response.status_code != 200:
        raise ValueError('Failed to get express ongoing orders data for {}'.format(user_id))
    else:
        return response.json()


def set_FDC_dax_config(driver_id, phone_type='ADR', app_version='5.211.0'):
    url = 'https://food-dax-capability.stg-myteksi.com/fooddaxcapability/dax/config'
    headers = {'Grab-Food-Driver-ID': driver_id}
    data = {
        "phoneType": phone_type,
        "appVersion": app_version
    }

    response = requests.post(url, headers=headers, data=data)
    if response.status_code != 200:
        raise ValueError('Failed to set FDC config for {}'.format(driver_id))
    else:
        return response.json()
